@@ -38,54 +38,45 @@ fit <- grpsel(x, y, group, penalty = 'grSubset+Ridge')
 coef(fit, lambda = 0.05, gamma = 0.1)
 
 ## -----------------------------------------------------------------------------
-cvfit <- cv.grpsel(x, y, group, penalty = 'grSubset+Ridge', nfold = 10) # 10-fold cross-validation
+fit <- cv.grpsel(x, y, group, penalty = 'grSubset+Ridge', nfold = 10) # 10-fold cross-validation
 
 ## -----------------------------------------------------------------------------
-plot(cvfit)
+plot(fit)
 
 ## -----------------------------------------------------------------------------
-coef(cvfit)
-predict(cvfit, x.new)
+coef(fit)
+predict(fit, x.new)
 
 ## -----------------------------------------------------------------------------
-y <- pmax(sign(y), 0)
-
+y <- rbinom(n, 1, 1 / (1 + exp(- x %*% beta)))
 fit <- cv.grpsel(x, y, group, loss = 'logistic')
 coef(fit)
 
 ## -----------------------------------------------------------------------------
-p <- 5
 x <- matrix(rnorm(n * p), n, p)
 y <- rowSums(x) + rnorm(n)
-group <- list(c(1, 2, 3), c(3, 4, 5))
+group <- list(1:6, 5:10)
 fit <- grpsel(x, y, group)
 
 ## -----------------------------------------------------------------------------
 coef(fit)
 
 ## -----------------------------------------------------------------------------
-p <- 10
 group <- rep(1:g, each = p / g)
-Sigma <- 0.9 ^ t(sapply(1:p, function(i, j) abs(i - j), 1:p))
-x <- matrix(rnorm(n * p), n, p)
-x <- t(chol(Sigma) %*% t(x))
+x <- matrix(rnorm(n * p), n, p) + matrix(rnorm(n), n, p)
 beta[which(group %in% 1:2)] <- 1 # First two groups are nonzero
 y <- x %*% beta + rnorm(n)
 fit <- cv.grpsel(x, y, group)
 coef(fit)
-fit <- cv.grpsel(x, y, group, ls = T)
+fit <- cv.grpsel(x, y, group, local.search = T)
 coef(fit)
 
 ## -----------------------------------------------------------------------------
-n <- 100
-p <- 10
 m <- 10 # Number of response variables
 beta <- matrix(0, p, m)
 beta[1:5, ] <- 1
 x <- matrix(rnorm(n * p), n, p)
 y <- x %*% beta + matrix(rnorm(n * m), n, m)
-x <- scale(x)
-y <- scale(y)
 
 y <- matrix(y, ncol = 1)
 x <- diag(m) %x% x
@@ -95,12 +86,10 @@ cvfit <- cv.grpsel(x, y, group)
 matrix(coef(cvfit)[- 1, , drop = F], ncol = m)
 
 ## -----------------------------------------------------------------------------
-n <- 100
-p <- 10
 x <- matrix(runif(n * p), n, p)
 y <- sinpi(2 * x[, 1]) + cospi(2 * x[, 2]) + rnorm(n, sd = 0.1)
 df <- 5
-splines <- lapply(1:p, function(j) splines::ns(x[, j], df = df))
+splines <- lapply(1:p, \(j) splines::ns(x[, j], df = df))
 x.s <- do.call(cbind, splines)
 group <- rep(1:p, each = df)
 fit <- cv.grpsel(x.s, y, group)
@@ -117,25 +106,23 @@ int.x1 <- (beta0 + colMeans(x.s[, - (1:df)]) %*% beta[- (1:df)])[, ]
 int.x2 <- (beta0 + colMeans(x.s[, - (1:df + df)]) %*% beta[- (1:df + df)])[, ]
 
 ggplot(x = seq(- 1, 1, length.out = 101)) +
-  stat_function(fun = function(x) sinpi(2 * x), aes(linetype = 'True function')) +
-  stat_function(fun = function(x) int.x1 + predict(splines[[1]], x) %*% beta[1:df], aes(linetype = 'Fitted function')) +
+  stat_function(fun = \(x) sinpi(2 * x), aes(linetype = 'True function')) +
+  stat_function(fun = \(x) int.x1 + predict(splines[[1]], x) %*% beta[1:df], aes(linetype = 'Fitted function')) +
   xlab('x') +
   ylab('f(x)')
 
 ggplot(x = seq(- 1, 1, length.out = 101)) +
-  stat_function(fun = function(x) cospi(2 * x), aes(linetype = 'True function')) +
-  stat_function(fun = function(x) int.x2 + predict(splines[[2]], x) %*% beta[1:df + df], aes(linetype = 'Fitted function')) +
+  stat_function(fun = \(x) cospi(2 * x), aes(linetype = 'True function')) +
+  stat_function(fun = \(x) int.x2 + predict(splines[[2]], x) %*% beta[1:df + df], aes(linetype = 'Fitted function')) +
   xlab('x') +
   ylab('f(x)')
 
 ## -----------------------------------------------------------------------------
-n <- 100
-p <- 10
 x <- matrix(rnorm(n * p), n, p)
-y <- x[, 1] + x[, 2] + x[, 3] + x[, 1] * x[, 2] + rnorm(n)
+y <- x[, 1] + x[, 2] + x[, 3] + x[, 1] * x[, 2] + rnorm(n, sd = 0.1)
 
 x.int <- model.matrix(~ - 1 + . ^ 2, data = as.data.frame(x))
 group <- c(1:p, mapply(c, combn(1:p, 2, simplify = F), 1:choose(p, 2) + p, SIMPLIFY = F))
 fit <- cv.grpsel(x.int, y, group)
-colnames(x.int)[which(coef(fit)[- 1] != 0)]
+colnames(x.int)[coef(fit)[- 1] != 0]
 
